@@ -34,22 +34,22 @@ class DocumentEmbedderTest(unittest.TestCase):
 
     @patch(PATCH_METHOD)
     def test_with_empty_corpus(self, mock):
-        self.assertIsNone(self.embedder(self.corpus[:0])[0])
-        self.assertIsNone(self.embedder(self.corpus[:0])[1])
+        self.assertIsNone(self.embedder.transform(self.corpus[:0])[0])
+        self.assertIsNone(self.embedder.transform(self.corpus[:0])[1])
         mock.request.assert_not_called()
         mock.get_response.assert_not_called()
         self.assertEqual(self.embedder._embedder._cache._cache_dict, dict())
 
     @patch(PATCH_METHOD, make_dummy_post(b'{"embedding": [0.3, 1]}'))
     def test_success_subset(self):
-        res, skipped = self.embedder(self.corpus[[0]])
+        res, skipped = self.embedder.transform(self.corpus[[0]])
         assert_array_equal(res.X, [[0.3, 1]])
         self.assertEqual(len(self.embedder._embedder._cache._cache_dict), 1)
         self.assertIsNone(skipped)
 
     @patch(PATCH_METHOD, make_dummy_post(b'{"embedding": [0.3, 1]}'))
     def test_success_shapes(self):
-        res, skipped = self.embedder(self.corpus)
+        res, skipped = self.embedder.transform(self.corpus)
         self.assertEqual(res.X.shape, (len(self.corpus), 2))
         self.assertEqual(len(res.domain.variables),
                          len(self.corpus.domain.variables) + 2)
@@ -58,7 +58,7 @@ class DocumentEmbedderTest(unittest.TestCase):
     @patch(PATCH_METHOD, make_dummy_post(b''))
     def test_empty_response(self):
         with self.assertWarns(RuntimeWarning):
-            res, skipped = self.embedder(self.corpus[[0]])
+            res, skipped = self.embedder.transform(self.corpus[[0]])
         self.assertIsNone(res)
         self.assertEqual(len(skipped), 1)
         self.assertEqual(len(self.embedder._embedder._cache._cache_dict), 0)
@@ -66,7 +66,7 @@ class DocumentEmbedderTest(unittest.TestCase):
     @patch(PATCH_METHOD, make_dummy_post(b'str'))
     def test_invalid_response(self):
         with self.assertWarns(RuntimeWarning):
-            res, skipped = self.embedder(self.corpus[[0]])
+            res, skipped = self.embedder.transform(self.corpus[[0]])
         self.assertIsNone(res)
         self.assertEqual(len(skipped), 1)
         self.assertEqual(len(self.embedder._embedder._cache._cache_dict), 0)
@@ -74,7 +74,7 @@ class DocumentEmbedderTest(unittest.TestCase):
     @patch(PATCH_METHOD, make_dummy_post(b'{"embeddings": [0.3, 1]}'))
     def test_invalid_json_key(self):
         with self.assertWarns(RuntimeWarning):
-            res, skipped = self.embedder(self.corpus[[0]])
+            res, skipped = self.embedder.transform(self.corpus[[0]])
         self.assertIsNone(res)
         self.assertEqual(len(skipped), 1)
         self.assertEqual(len(self.embedder._embedder._cache._cache_dict), 0)
@@ -82,7 +82,7 @@ class DocumentEmbedderTest(unittest.TestCase):
     @patch(PATCH_METHOD, make_dummy_post(b'{"embedding": [0.3, 1]}'))
     def test_persistent_caching(self):
         self.assertEqual(len(self.embedder._embedder._cache._cache_dict), 0)
-        self.embedder(self.corpus[[0]])
+        self.embedder.transform(self.corpus[[0]])
         self.assertEqual(len(self.embedder._embedder._cache._cache_dict), 1)
         self.embedder._embedder._cache.persist_cache()
 
@@ -98,7 +98,7 @@ class DocumentEmbedderTest(unittest.TestCase):
         embedder = DocumentEmbedder(language='sl')
         embedder.clear_cache()
         self.assertEqual(len(embedder._embedder._cache._cache_dict), 0)
-        embedder(self.corpus[[0]])
+        embedder.transform(self.corpus[[0]])
         self.assertEqual(len(embedder._embedder._cache._cache_dict), 1)
         embedder._embedder._cache.persist_cache()
 
@@ -116,33 +116,27 @@ class DocumentEmbedderTest(unittest.TestCase):
         embedder = DocumentEmbedder(aggregator='max')
         embedder.clear_cache()
         self.assertEqual(len(embedder._embedder._cache._cache_dict), 0)
-        embedder(self.corpus[[0]])
+        embedder.transform(self.corpus[[0]])
         self.assertEqual(len(embedder._embedder._cache._cache_dict), 1)
         embedder._embedder._cache.persist_cache()
 
         embedder = DocumentEmbedder(aggregator='min')
         self.assertEqual(len(embedder._embedder._cache._cache_dict), 1)
-        embedder(self.corpus[[0]])
+        embedder.transform(self.corpus[[0]])
         self.assertEqual(len(embedder._embedder._cache._cache_dict), 2)
 
-    @patch(PATCH_METHOD, make_dummy_post(b'{"embedding": [0.3, 1]}'))
-    def test_with_statement(self):
-        with self.embedder as embedder:
-            res, skipped = embedder(self.corpus[[0]])
-            assert_array_equal(res.X, [[0.3, 1]])
-
     @patch(PATCH_METHOD, make_dummy_post(b'{"embedding": [0.3, 1]}'))
     def test_cancel(self):
         self.assertFalse(self.embedder._embedder._cancelled)
         self.embedder._embedder._cancelled = True
         with self.assertRaises(Exception):
-            self.embedder(self.corpus[[0]])
+            self.embedder.transform(self.corpus[[0]])
 
     @patch(PATCH_METHOD, side_effect=OSError)
     def test_connection_error(self, _):
         embedder = DocumentEmbedder()
         with self.assertRaises(ConnectionError):
-            embedder(self.corpus[[0]])
+            embedder.transform(self.corpus[[0]])
 
     def test_invalid_parameters(self):
         with self.assertRaises(ValueError):
@@ -150,6 +144,6 @@ class DocumentEmbedderTest(unittest.TestCase):
         with self.assertRaises(ValueError):
             self.embedder = DocumentEmbedder(aggregator='average')
 
-    def test_invalid_corpus_type(self):
-        with self.assertRaises(ValueError):
-            self.embedder(self.corpus[0])
+
+if __name__ == "__main__":
+    unittest.main()
