@@ -29,6 +29,12 @@ class Topic(Table):
 class Topics(Table):
     """ Dummy wrapper for Table so signals can distinguish All Topics from Data.
     """
+    @classmethod
+    def from_file(cls, filename):
+        t = super().from_file(filename)
+        if not isinstance(t, cls):
+            t = cls.from_numpy(t.domain, t.X, t.Y, t.metas, t.W, attributes=t.attributes)
+        return t
 
 
 class GensimProgressCallback(Metric):
@@ -159,11 +165,10 @@ class GensimWrapper:
         metas[-1]._out_format = '%.2e'
 
         domain = Domain([], metas=metas)
-        t = Topic.from_numpy(domain,
-                             X=np.zeros((num_words, 0)),
-                             metas=data)
-        t.W = data[:, 1]
-        t.name = 'Topic {}'.format(topic_id + 1)
+        t = Topic.from_numpy(
+            domain, X=np.zeros((num_words, 0)), metas=data, W=data[:, 1]
+        )
+        t.name = "Topic {}".format(topic_id + 1)
 
         # needed for coloring in word cloud
         t.attributes["topic-method-name"] = self.model.__class__.__name__
