@@ -45,7 +45,7 @@ def search(
     else:  # mode == "authors":
         return api.search_authors(
             max_tweets=max_tweets,
-            authors=word_list,
+            authors=[word.strip("@") for word in word_list],
             collecting=collecting,
             callback=advance,
         )
@@ -90,10 +90,9 @@ class OWTwitter(OWWidget, ConcurrentWidgetMixin):
         want_main_area = False
         resizing_enabled = False
 
-        cm_key = CredentialManager("Twitter Bearer Token")
-
         def __init__(self, parent):
             super().__init__()
+            self.cm_key = CredentialManager("Twitter Bearer Token")
             self.parent = parent
 
             box = gui.vBox(self.controlArea, "Bearer Token")
