@@ -1,5 +1,4 @@
 import unittest
-from unittest.mock import Mock
 
 import Orange
 import numpy as np
@@ -106,6 +105,18 @@ class TestWordEnrichment(WidgetTest):
         self.send_signal(w.Inputs.selected_data, None)
         self.assertFalse(self.widget.Error.no_bow_features.is_shown())
 
+    def test_selected_data_is_table(self):
+        w = self.widget
+        iris = Table("iris")
+
+        self.send_signal(w.Inputs.data, self.corpus_vect)
+        self.send_signal(w.Inputs.selected_data, iris[:10])
+        self.assertTrue(self.widget.Error.no_bow_features.is_shown())
+
+        self.send_signal(w.Inputs.data, self.corpus_vect)
+        self.send_signal(w.Inputs.selected_data, self.subset_corpus)
+        self.assertFalse(self.widget.Error.no_bow_features.is_shown())
+
     def test_all_selected(self):
         w = self.widget
 
@@ -141,50 +152,6 @@ class TestWordEnrichment(WidgetTest):
         self.send_signal(w.Inputs.data, self.corpus_vect)
         self.assertFalse(self.widget.Error.no_words_overlap.is_shown())
 
-    @unittest.skipIf(
-        Orange.__version__ < "3.24.0", "wait_until_finished not supported")
-    def test_input_info(self):
-        w = self.widget
-        input_sum = w.info.set_input_summary = Mock()
-
-        self.send_signal(w.Inputs.selected_data, self.subset_corpus)
-        self.send_signal(w.Inputs.data, self.corpus_vect)
-
-        input_sum.assert_called_with(
-            "5923|1204", "Total words: 5923\nWords in subset: 1204")
-
-        self.wait_until_stop_blocking()
-        self.send_signal(w.Inputs.selected_data, None)
-        self.send_signal(w.Inputs.data, None)
-        input_sum.assert_called_with(w.info.NoInput)
-
-    @unittest.skipIf(
-        Orange.__version__ < "3.24.0", "wait_until_finished not supported")
-    def test_output_info(self):
-        w = self.widget
-        w.filter_p_value = 1e-3
-        w.filter_by_p = True
-        w.filter_by_fdr = False
-
-        self.send_signal(w.Inputs.selected_data, self.subset_corpus)
-        self.send_signal(w.Inputs.data, self.corpus_vect)
-        self.wait_until_finished(timeout=100000)
-
-        self.assertEqual(w.info_fil.text(), "Words displayed: 3")
-
-        # test fdr filter
-        w.filter_by_p = True
-        w.filter_p_value = 1e-4
-        w.filter_by_fdr = True
-        w.filter_fdr_value = 1e-4
-        w.filter_and_display()
-        self.assertEqual(w.info_fil.text(), "Words displayed: 0")
-
-        self.send_signal(w.Inputs.selected_data, None)
-        self.assertEqual(w.info_fil.text(), "Words displayed: 0")
-        self.send_signal(w.Inputs.data, None)
-        self.assertEqual(w.info_fil.text(), "Words displayed: 0")
-
     @unittest.skipIf(
         Orange.__version__ < "3.24.0", "wait_until_finished not supported")
     def test_filter_changed(self):
@@ -267,6 +234,37 @@ class TestWordEnrichment(WidgetTest):
             decimal=5,
         )
 
+    def test_output(self):
+        widget = self.widget
+
+        self.send_signal(widget.Inputs.data, self.corpus_vect)
+        self.send_signal(widget.Inputs.selected_data, self.subset_corpus)
+        self.wait_until_finished(timeout=100000)
+
+        # output should correspond to shown results
+        widget.filter_by_p = True
+        widget.filter_p_value = 1e-3
+        widget.filter_by_fdr = False
+        widget.filter_fdr_value = 0.01
+
+        widget.filter_and_display()
+        widget.commit()
+        output = self.get_output(self.widget.Outputs.words)
+        self.assertEqual(
+            len(output), int(widget.info_fil.text().split(": ")[1])
+        )
+
+        # test empty results
+        widget.filter_by_p = True
+        widget.filter_p_value = 1e-3
+        widget.filter_by_fdr = True
+        widget.filter_fdr_value = 0.01
+
+        widget.filter_and_display()
+        widget.commit()
+        output = self.get_output(self.widget.Outputs.words)
+        self.assertEqual(len(output), 0)
+
 
 if __name__ == "__main__":
     unittest.main()
